.. nitools_index

Nitools
=======
Basic Neuroimaging functionality for Nifti, Gifti, Cifti
Data structures. Basic useful functions missing from nibabel and nilearn

Developed and maintained by the Diedrichsenlab.

Installation
------------
For developement, please clone the Github repository:
https://github.com/DiedrichsenLab/nitools

To simply use it, you can install the package with pip:

``pip install neuroimagingtools``


Nifti and Volume functions
--------------------------
.. automodule:: volume
    :members:

Gifti functions
---------------------------
.. automodule:: gifti
    :members:


Cifti functions
-----------------------
.. automodule:: cifti
    :members:

Color maps and files
-----------------------
.. automodule:: color
    :members:

Border functions
-----------------------
.. automodule:: border
    :members:


* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
